Name:           mkosi
Version:        24.3
Release:        %mkrel 1
Summary:        Create bespoke OS images
Group:          Development/Tools
License:        LGPLv2+
URL:            https://github.com/systemd/mkosi
Source0:        https://github.com/systemd/mkosi/archive/v%{version}/%{name}-%{version}.tar.gz
ExclusiveArch:	x86_64
BuildArch:      noarch
BuildRequires:  python3-devel
BuildRequires:  pyproject-rpm-macros
BuildRequires:  python3-pytest
BuildRequires:  python3dist(setuptools-scm)

Recommends:     dnf
Recommends:     gnupg
Recommends:     xz
Recommends:     tar
Recommends:     e2fsprogs
Recommends:     squashfs-tools
Recommends:     cryptsetup
Recommends:     binutils
Recommends:     debootstrap
Recommends:     arch-install-scripts
Recommends:     edk2-ovmf
Recommends:     btrfs-progs
Recommends:     dosfstools
Recommends:     cpio
Recommends:     zstd
Recommends:     python3dist(argcomplete)
Recommends:     python3dist(cryptography)
Recommends:     python3dist(pexpect)

%description
A fancy wrapper around "dnf --installroot", "apt", "pacman", and "zypper" that
generates disk images with a number of bells and whistles.

Generated images are tailored to the purpose: GPT partitions,
systemd-boot or grub2, images for containers, VMs, initrd, and extensions.

Mkosi can boot an image via QEMU or systemd-nspawn, or simply start a shell in
chroot, burn the image to a device, connect to a running VM via ssh, extract
logs and coredumps, and also serve an image over HTTP.

See https://mkosi.systemd.io/ for documentation.

%prep
%autosetup -p1

%generate_buildrequires
%pyproject_buildrequires

%build
%if ! 0%{?mageia}
tools/make-man-page.sh
%endif

%pyproject_wheel

%install
%pyproject_install
%pyproject_save_files mkosi

%if ! 0%{?mageia}
mkdir -p %{buildroot}%{_mandir}/man1
ln -s -t %{buildroot}%{_mandir}/man1/ \
         ../../../..%{python3_sitelib}/mkosi/resources/mkosi.1
%endif

%files -f %pyproject_files
%license LICENSE
%doc README.md
%_bindir/mkosi
%_bindir/mkosi-initrd
#%%_mandir/man1/mkosi.1*

%check
%if %{with tests}
%pytest tests/ -v

# just a smoke test for syntax or import errors
%py3_test_envvars %{buildroot}%{_bindir}/mkosi --help >/dev/null
%endif



%changelog
* Wed Aug 28 2024 mrambo3501 <mrambo3501> 24.3-1.mga10
+ Revision: 2092023
- version 24.3
- BR python3dist(setuptools-scm)
- fix files list

* Sun Jul 21 2024 wally <wally> 23.1-1.mga10
+ Revision: 2082213
- new version 23.1

* Sat Dec 09 2023 wally <wally> 14-2.mga10
+ Revision: 2016169
- rebuild for py3.12

* Sun Dec 04 2022 wally <wally> 14-1.mga9
+ Revision: 1917516
- new version 14

* Sat Jul 23 2022 wally <wally> 13-3.mga9
+ Revision: 1870534
- another update for mga repo url patch

* Sat Jul 23 2022 wally <wally> 13-2.mga9
+ Revision: 1870529
- update mga repo url patch

* Sat Jul 23 2022 wally <wally> 13-1.mga9
+ Revision: 1870472
- new version 13

* Sat Mar 26 2022 umeabot <umeabot> 12-3.mga9
+ Revision: 1828450
- Mageia 9 Mass Rebuild

* Mon Feb 14 2022 tv <tv> 12-2.mga9
+ Revision: 1775081
- Rebuild for python-3.10

* Mon Dec 06 2021 wally <wally> 12-1.mga9
+ Revision: 1760912
- new version 12

* Sun Aug 08 2021 wally <wally> 10-1.mga9
+ Revision: 1740434
- new version 10

* Tue Apr 06 2021 wally <wally> 9-1.mga9
+ Revision: 1713897
- new version 9

* Mon Mar 15 2021 wally <wally> 8-2.mga9
+ Revision: 1703637
- rebuild for python 3.9

* Sun Dec 06 2020 wally <wally> 8-1.mga8
+ Revision: 1653817
- new version 8

* Sun Oct 11 2020 wally <wally> 6-1.mga8
+ Revision: 1633468
- new version 6

* Sat Feb 15 2020 umeabot <umeabot> 5-2.mga8
+ Revision: 1526967
- Mageia 8 Mass Rebuild

* Sun Jul 07 2019 wally <wally> 5-1.mga8
+ Revision: 1419267
- new version 5

* Wed Jan 09 2019 wally <wally> 4-3.mga7
+ Revision: 1353782
- add patch to not force x86_64 arch in repository urls

* Thu Sep 20 2018 umeabot <umeabot> 4-2.mga7
+ Revision: 1279938
- Mageia 7 Mass Rebuild

* Mon Sep 10 2018 wally <wally> 4-1.mga7
+ Revision: 1258189
- new version 4
- sync patches with Fedora
+ mitya <mitya>
- imported package mkosi


* Fri Jun 23 2017 Zbigniew Jędrzejewski-Szmek <zbyszek@in.waw.pl> - 2-1
- Update to latest version (#1464285)

* Fri Feb 10 2017 Fedora Release Engineering <releng@fedoraproject.org> - 1-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_26_Mass_Rebuild

* Mon Dec 19 2016 Miro Hrončok <mhroncok@redhat.com> - 1-2
- Rebuild for Python 3.6

* Thu Nov  3 2016 Zbigniew Jędrzejewski-Szmek <zbyszek@in.waw.pl> - 1-1
- Initial version
